@@ -1,6 +1,6 @@
 #' @importFrom dplyr group_data
 #' @export
-group_data.forest <- function(.data) {
+group_data.forest <- function(.data, ...) {
   modify_roots(group_data)(.data)
 }
 
@@ -18,25 +18,25 @@ group_indices.forest <- function(.data, ...) {
 
 #' @importFrom dplyr group_vars
 #' @export
-group_vars.forest <- function(x) {
+group_vars.forest <- function(x, ...) {
   modify_roots(group_vars)(x)
 }
 
 #' @importFrom dplyr groups
 #' @export
-groups.forest <- function(x) {
+groups.forest <- function(x, ...) {
   modify_roots(groups)(x)
 }
 
 #' @importFrom dplyr group_size
 #' @export
-group_size.forest <- function(x) {
+group_size.forest <- function(x, ...) {
   modify_roots(group_size)(x)
 }
 
 #' @importFrom dplyr n_groups
 #' @export
-n_groups.forest <- function(x) {
+n_groups.forest <- function(x, ...) {
   modify_roots(n_groups)(x)
 }
 
